---
title: Instant Messaging: It's not about the app
date: 2021-01-20 06:30
author: Edward Maurer
blog_id: blog
category: misc
---

Translations:
- [Deutsch](https://xmpp.org/2021/01/instant-messaging-es-geht-nicht-um-die-app/)
- [Español](https://xmpp.org/2021/01/mensajeria-instantanea-no-se-trata-de-la-aplicacion/)
- [Française](https://xmpp.org/2021/01/messagerie-instantanee-il-ne-sagit-pas-de-lapplication/)
- [Română](https://xmpp.org/2021/01/mesagerie-instantanee-nu-este-vorba-despre-aplicatie/)

Several people have recently reached out to me asking what kind of messenger they should be using now - they said that they actually do not understand what they should be concerned about and whether they should switch from one of the commonly known messengers to another. 
I wondered how to answer this. Obviously, I could simply have advocated for XMPP (Extensible Messaging and Presence Protocol), but then I thought this might not be a helpful answer by itself. Often, people just make a quick decision about their communication software and this usually isn't a well-founded choice; and so they will end up switching to yet another messenger later.

Many will actually add another messenger to their ever-increasing collection of messengers, which is likely more frustrating than helpful. This brings me back to the original question: What issue or what problem does one want to solve here? What are the incentives? Can one find a solution with a better technological basis that avoids the hype and doesn't involve installing multiple messenger apps?

Different people have different considerations for answering that question – some require effective data privacy, or data sovereignty, or simply the ability to reach all of their contacts from one place. However, moving from one messaging system to another will often mean leaving behind some contacts. Many messaging systems also require a  phone number, which isn't great for privacy.

### Sovereignty of Communication

As you might have suspected, I will advocate for XMPP. I think the first choice one should make is not which messenger to use, but which underlying software technology. Consider the choice of technology first, before jumping from one recommendation to the next.

> XMPP is an open protocol, like HTTP is for the web. It does not matter what your website looks like, everyone can interact with it. This principle is the idea behind XMPP, but for instant messaging.

At the XMPP Standards Foundation, and with many others involved in this open technology, we think that XMPP is a great choice as a communication technology, not just with respect to data privacy. XMPP has been around for over twenty years, and a lot of practical experience has been gathered in that time. This includes many key indicators for the choice of technology and enabling sovereignty of communication, as it supports:

- Decentralization of communication services (federation)
- Standardization and extensibility of technology
- Interoperablility
- Innovation and the use of open development
- Privacy and control, also by using end-to-end encryption

> XMPP provides defined information how to handle the communication in a network. The user decides which messaging software suits or where the data should be stored.

In contrast to the current situation where other people suggest you use their preferred messenger, in the XMPP universe you have a free choice of many messengers – pick whichever one you like, not what others like 
until the next internet fad. The difference is that, regardless of your messaging app or which app your friends use, you still have the comfort of being on the same network with all of your contacts, independent of your choice today. I think this is a real solution.

### It's not about the app but about the technology

Consider a decision on the technology you intend to use, and then decide which messenger suits you or your environment. XMPP and its community have amassed a variety of experience, which has been successfully 
utilized in a great deal of software. We think this is a good solution for most people and organizations out there, and the internet as a whole – and it is open for all of us to make innovations for the future.

> XMPP has not just a wide range of messaging software; there is also various server software and the tools (libraries) to build infrastructure yourself.

There isn't a single way communication apps must be designed. Make a sustainable decision for a standardized technology – for that purpose, and many more, we recommend the use of XMPP!

If you are interested in making a choice for the next decade, let me point you to some further reading:

- [Getting started](https://xmpp.org/getting-started/), XMPP Standards Foundation
- XSF Blog article: [It’s all about choices and control](https://xmpp.org/2015/01/its-all-about-choices-and-control/) from Laura, written in 2015
- [Modern XMPP](https://docs.modernxmpp.org/), website supporting developers & newcomers to get started with XMPP
- Commentary in the XMPP Community (not all in English):
    - [Eine Chance für XMPP?](https://www.jabber.de/eine-chance-fuer-xmpp/), jabber.de
    - [How to ensure your Instant Messaging solution offers users privacy and security](https://www.erlang-solutions.com/blog/how-to-ensure-your-instant-messaging-solution-offers-users-privacy-and-security.html), Erlang Solutions
    - [Mastodon post](https://pouet.april.org/@aprilorg/105520799332659637), Association April
    - [Twitter post](https://twitter.com/MovimNetwork/status/1351138046029279239), Movim Network
    

This blog post is published under CC BY-SA 4.0 license.
   
